@@ -32,7 +32,7 @@ class CommonTestCase(unittest.TestCase):
 
         eventCode1 = "pascal-case-columns"
         eventCode2 = "not-pascal-case-columns"
-        eventCode3 = "dimension-keys"
+        eventCode3 = "dimension-keys-pascal"
 
         eventResults1 = []
         eventResults2 = []
